import React, { useState } from "react";
import styled from "styled-components";
import Button from "../../util/Button";
import Loading from "../../util/Loading";
import { dispatch, useGameId, usePlayerName } from "../../../domain/gameStore";

const Label = styled.span`
  padding: 0.2em;
`

const FormInput = styled.input`
  border-radius: 0px;
  border: #666 solid 1px;
  background-color: #181a1b;
  color: #eee;
  padding: 0.5em;
`

const FormButton = styled(Button)`
  padding: 1em;
  margin: 0.2em;
  margin-top: 0.3em;
`

const JoinForm = () => {
  const gameId = useGameId();
  const playerName = usePlayerName();
  const [loading, setLoading] = useState(false);
  const [failed, setFailed] = useState(false);

  if (loading) {
    return <Loading/>
  }

  const onJoinGame = async () => {
    // TODO would like to support re-joining a game you left
    setLoading(true);
    try {
      await dispatch.joinGame();
    } catch (err) {
      // failed to join the game
      setFailed(true);
      setLoading(false);
      return;
    }
    setFailed(false);
  };
  const cannotJoinGame = !playerName || playerName.length === 0;

  return (
    <>
      {failed && <Label>Failed to join the game! Maybe try a different name?</Label>}
      <Label>Joining {gameId}...</Label>
      <Label>Player Name</Label>
      <FormInput
        type="text" 
        value={playerName || ""} 
        onChange={({ target }) => dispatch.setPlayerName(target.value)} 
        onKeyDown={({ key }) => { if (key === "Enter") { onJoinGame() }}}
      />
      <FormButton onClick={onJoinGame} disabled={cannotJoinGame}>Join Game</FormButton>
    </>
  );
};

export default JoinForm;
