import React from "react";
import styled from "styled-components";
import ClickToCopy from "../../util/ClickToCopy";
import DelayedButton from "../../util/DelayedButton";
import { dispatch, useGameId, usePlayerName } from "../../../domain/gameStore";

const Label = styled.span`
  padding: 0.2em;
`

const StyledDelayButton = styled(DelayedButton)`
  padding: 1em;
  margin: 0.2em;
  margin-top: 0.3em;
`

const getUrl = gameId => {
  const u = new URL(window.location.href);
  u.searchParams.append("join", gameId);
  return u.href;
}

const LobbyInfo = () => {
  const gameId = useGameId();
  const playerName = usePlayerName();

  return (
    <>
      <Label>Playing as {playerName}</Label>
      <Label>Use this link to invite other players:</Label>
      <Label><ClickToCopy text={getUrl(gameId)} /></Label>
      <StyledDelayButton 
        onEnd={dispatch.startRound} 
        countDownFormatter={rem => `Click to cancel, ${rem}s...`}
      >
        Start Game
      </StyledDelayButton>
    </>
  )
};

export default LobbyInfo;
